@@ -24,9 +24,10 @@ def addgeoip(request):
     allowed_countries = getattr(settings, 'COUNTRY_BLOCK_ALLOWED_COUNTRIES', server_location)
 
     #if the visiting user has staff status, let them see everything
-    if hasattr(request, 'user') and request.user.is_staff:
-        return {'country' : 'Staff Overwrite',
-                'in_country' : True}
+    if hasattr(request, 'user'):
+        if request.user.is_staff:
+            return {'country' : 'Staff Overwrite',
+                    'in_country' : True}
 
     if ip or not server_location:
         user_country = GeoIP().country_code(ip)
